@@ -30,7 +30,7 @@ sub compute_scan {
 	}
 
 	### NOTE : dispatches the list of tokens
-	$scans->scan($lexertable->get_table_hash, $self->{tokensunitoffile}->get_file_tokens_list);
+	$self->{scans}->scan($lexertable->get_table_hash, $self->{tokensunitoffile}->get_file_tokens_list);
 
 ### FIXME put somehwere else :	my $parser = parser->new->compute_parse($lexertable, $self->{scans});
 
