@@ -28,16 +28,16 @@ sub parse {
 		### as bracein and braceout
 		if ($word == "bracein") {
 			my $node = parsetreenode->new("bracein");
-			$currentnode->add_child_node(\$node);
 			push(@parentnodes, $currentnode);
 			$parentnodecounter++;
-			$currentnode = $node;
+			$currentnode = @parentnodes[$parentnodecounter-1];
+			$currentnode->add_child_node(\$node); ### adds to $currentnode's children
 			next;
 		} 
 		if ($word == "braceout") {
 			my $node = parsetreenode->new("braceout");
-			$currentnode->add_child_node(\$node);
-			$currentnode = @parentnode[--$parentnodecounter];
+			$currentnode->add_child_node(\$node); ### adds to $currentnode's children
+			$currentnode = @parentnodes[--$parentnodecounter];
 		}	
 
 		if (defined($word)) { ### NOTE : must be string also
